@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -89,6 +89,9 @@ public class DeleteSubscriptionAction extends AbstractSubscribeAction {
             final Subscription subscription = new Subscription();
             subscription.setContext(context);
             subscription.setId(id);
+            if (null == subscription.getSession()) {
+                subscription.setSession(subscribeRequest.getServerSession());
+            }
             subscribeService.unsubscribe(subscription);
         }
         return new AJAXRequestResult(Integer.valueOf(1), "json");
